#include "diff_pressure_hw.h"

sbit DIFF_PRESSURE_CS           at PORTA5_bit;
sbit DIFF_PRESSURE_CS_DIR       at DDA5_bit;
sbit DIFF_PRESSURE_RDY          at PINB6_bit;
sbit DIFF_PRESSURE_RDY_DIR      at DDB6_bit;


void system_setup( void );

void main()
{
        //Local Declarations
        int32_t buffer = 0;
        char uart_text[20] = { 0 };
        float difference = 0.;

        system_setup();
        while (1)
        {
                if ( diff_pressure_read_adc( &buffer ) == OK )
                {
                        LongToStr( buffer, uart_text );
                        UART1_Write_Text( "ADC Value: " );
                        Ltrim( uart_text );
                        UART1_Write_Text( uart_text );
                        UART1_Write_Text( "\r\n" );
                        difference = diff_pressure_get_kpa_difference( buffer );
                        sprintf( uart_text, "KPA Difference: %.2f", difference );
                        UART1_Write_Text( uart_text );
                        UART1_Write_Text( "\r\n" );
                        Delay_ms( 100 );
                        buffer = 0;
                }
                else if ( diff_pressure_read_adc( &buffer ) == OVH )
                        UART1_Write_Text( "Overflow happened\r\n" );
                else if ( diff_pressure_read_adc( &buffer ) == OVL )
                        UART1_Write_Text( "Underflow happened\r\n" );
        }



}

void system_setup( void )
{
        //GPIOs
        DIFF_PRESSURE_CS_DIR = 1;
        DIFF_PRESSURE_RDY_DIR = 0;

        //UART
        UART1_Init( 9600 );
        Delay_ms(200);
        UART1_Write_Text( "UART Initialized\r\n" );

        // SPI
        SPI1_Init_Advanced( _SPI_MASTER, _SPI_FCY_DIV2, _SPI_CLK_LO_LEADING );
        Delay_ms(200);
        UART1_Write_Text( "SPI Initialized\r\n" );

        //Diff Pressure Click
        diff_pressure_init();
        UART1_Write_Text( "Diff Pressure Click Initialized\r\n" );
}